pub struct TursoTransaction<'conn> { /* private fields */ }Expand description
A transaction handle for TursoExecutor.
Created with TursoExecutor::transaction. Queries executed via this
handle are scoped to the same transaction until committed or rolled back.
Implementations
Sourceimpl TursoTransaction<'_>
impl TursoTransaction<'_>
Sourcepub fn raw(&self) -> &Transaction<'_>
pub fn raw(&self) -> &Transaction<'_>
Returns the underlying Turso transaction handle.
Sourcepub async fn query_void(&self, query: Query) -> Result<(), DBError>
pub async fn query_void(&self, query: Query) -> Result<(), DBError>
Executes a query inside this transaction, discarding results.
Sourcepub async fn query_one<T: FromRow + Send + 'static>(
&self,
query: Query,
) -> Result<Option<T>, DBError>
pub async fn query_one<T: FromRow + Send + 'static>( &self, query: Query, ) -> Result<Option<T>, DBError>
Executes a query inside this transaction, returning at most one row.